==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/lo.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "The given name is too long",
    "The given web address is too long" : "The given web address is too long",
    "The given web address is not a valid URL" : "The given web address is not a valid URL",
    "The given legal notice address is too long" : "The given legal notice address is too long",
    "The given legal notice address is not a valid URL" : "The given legal notice address is not a valid URL",
    "The given privacy policy address is too long" : "The given privacy policy address is too long",
    "The given privacy policy address is not a valid URL" : "The given privacy policy address is not a valid URL",
    "The given slogan is too long" : "The given slogan is too long",
    "The given color is invalid" : "The given color is invalid",
    "Disable-user-theming should be true or false" : "Disable-user-theming should be true or false",
    "Saved" : "Saved",
    "Invalid app given" : "Invalid app given",
    "Invalid type for setting \"defaultApp\" given" : "Invalid type for setting \"defaultApp\" given",
    "Invalid setting key" : "Invalid setting key",
    "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded" : "No file uploaded",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
    "Theming" : "Theming",
    "Appearance and accessibility" : "Appearance and accessibility",
    "PHP Imagick module" : "PHP Imagick module",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it.",
    "Dark theme with high contrast mode" : "Dark theme with high contrast mode",
    "Enable dark high contrast mode" : "Enable dark high contrast mode",
    "Similar to the high contrast mode, but with dark colours." : "Similar to the high contrast mode, but with dark colours.",
    "Dark theme" : "ໂມດກາງຄືນ",
    "Enable dark theme" : "ນໍາໃຊ້ໂມດກາງຄືນ ",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "A dark theme to ease your eyes by reducing the overall luminosity and brightness.",
    "System default theme" : "System default theme",
    "Enable the system default" : "Enable the system default",
    "Using the default system appearance." : "Using the default system appearance.",
    "Dyslexia font" : "ຕົວອັກສອນ Dyslexia",
    "Enable dyslexia font" : "ເປີດໃຊ້ຟອນ dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ເປັນຕົວພິມ/ຕົວອັກສອນຟຣີທີ່ອອກແບບມາເພື່ອຫຼຸດຜ່ອນບາງຄວາມຜິດພາດການອ່ານທົ່ວໄປທີ່ເກີດຈາກອາການຜິດປົກກະຕິໃນການຕໍ່ຄຳສັບ",
    "High contrast mode" : "ໂໝດຄວາມຄົມຊັດສູງ",
    "Enable high contrast mode" : "ເປີດໃຊ້ໂໝດຄວາມຄົມຊັດສູງ",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "ໂໝດຄວາມຄົມຊັດສູງເພື່ອຜ່ອນຄາຍການນຳທາງຂອງທ່ານ. ຄຸນນະພາບການເບິ່ງເຫັນຈະຫຼຸດລົງແຕ່ຄວາມຊັດເຈນຈະເພີ່ມຂຶ້ນ.",
    "Light theme" : "Light theme",
    "Enable the default light theme" : "Enable the default light theme",
    "The default light appearance." : "The default light appearance.",
    "Legal notice" : "Legal notice",
    "Privacy policy" : "ນະໂຍບາຍຄວາມເປັນສ່ວນຕົວ",
    "Adjust the Nextcloud theme" : "Adjust the Nextcloud theme",
    "Name" : "ຊື່",
    "Web link" : "Web link",
    "a safe home for all your data" : "a safe home for all your data",
    "Slogan" : "Slogan",
    "Primary color" : "Primary color",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema.",
    "Legal notice link" : "Legal notice link",
    "Privacy policy link" : "Privacy policy link",
    "Header logo" : "Header logo",
    "Upload new header logo" : "Upload new header logo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Upload new favicon",
    "User settings" : "User settings",
    "Disable user theming" : "Disable user theming",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons.",
    "Background color" : "Background color",
    "Upload new logo" : "Upload new logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Upload new background and login image",
    "Background and login image" : "Background and login image",
    "Advanced options" : "Advanced options",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
    "Unable to apply the setting." : "Unable to apply the setting.",
    "Appearance and accessibility settings" : "Appearance and accessibility settings",
    "Misc accessibility options" : "Misc accessibility options",
    "Enable blur background filter (may increase GPU load)" : "Enable blur background filter (may increase GPU load)",
    "Customization has been disabled by your administrator" : "Customization has been disabled by your administrator",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements.",
    "Background and color" : "Background and color",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "The background can be set to an image from the default set, a custom uploaded image, or a plain color.",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "Disable all keyboard shortcuts",
    "Current selected app: {app}, position {position} of {total}" : "Current selected app: {app}, position {position} of {total}",
    "Move up" : "Move up",
    "Move down" : "Move down",
    "Select a background from your files" : "Select a background from your files",
    "Select background" : "Select background",
    "No background has been selected" : "No background has been selected",
    "Custom background" : "Custom background",
    "Plain background" : "Plain background",
    "Default background" : "Default background",
    "Theme selection is enforced" : "Theme selection is enforced",
    "Could not set the app order" : "Could not set the app order",
    "Could not reset the app order" : "Could not reset the app order",
    "Navigation bar settings" : "Navigation bar settings",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo.",
    "The default app can not be changed because it was configured by the administrator." : "The default app can not be changed because it was configured by the administrator.",
    "The app order was changed, to see it in action you have to reload the page." : "The app order was changed, to see it in action you have to reload the page.",
    "Reset default app order" : "Reset default app order",
    "Could not set primary color" : "Could not set primary color",
    "Reset primary color" : "Reset primary color",
    "Could not set global default apps" : "Could not set global default apps",
    "Default app" : "Default app",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked.",
    "Use custom default app" : "Use custom default app",
    "Global default app" : "Global default app",
    "Global default apps" : "Global default apps",
    "Default app priority" : "Default app priority",
    "If an app is not enabled for a user, the next app with lower priority is used." : "If an app is not enabled for a user, the next app with lower priority is used.",
    "Select a custom color" : "Select a custom color",
    "Reset to default" : "Reset to default",
    "Upload" : "ອັບໂຫຼດ",
    "Remove background image" : "Remove background image",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ການເຂົ້າເຖິງທົ່ວໄປແມ່ນມີຄວາມສໍາຄັນຫຼາຍສໍາລັບພວກເຮົາ. ພວກເຮົາປະຕິບັດຕາມມາດຕະຖານເວັບ ແລະກວດສອບເພື່ອເຮັດໃຫ້ທຸກຢ່າງສາມາດໃຊ້ໄດ້ໂດຍບໍ່ໃຊ້ເມົາສ໌, ແລະຊອບແວຊ່ວຍເຫຼືອເຊັ່ນ screenreaders. ພວກເຮົາຕັ້ງເປົ້າໝາຍໃຫ້ສອດຄ່ອງກັບ {guidelines} ຂໍ້ແນະນຳການເຂົ້າຫາເນື້ອຫາເວັບ{linkend} 2.1 ໃນລະດັບ AA, ດ້ວຍຮູບແບບສີສັນຄົມຊັດສູງ ແມ້ແຕ່ຢູ່ໃນລະດັບ AAA.",
    ". Unable to apply the setting." : ". Unable to apply the setting."
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/lo.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "The given name is too long",
    "The given web address is too long" : "The given web address is too long",
    "The given web address is not a valid URL" : "The given web address is not a valid URL",
    "The given legal notice address is too long" : "The given legal notice address is too long",
    "The given legal notice address is not a valid URL" : "The given legal notice address is not a valid URL",
    "The given privacy policy address is too long" : "The given privacy policy address is too long",
    "The given privacy policy address is not a valid URL" : "The given privacy policy address is not a valid URL",
    "The given slogan is too long" : "The given slogan is too long",
    "The given color is invalid" : "The given color is invalid",
    "Invalid setting key" : "Invalid setting key",
    "Saved" : "Saved",
    "Invalid app given" : "Invalid app given",
    "Invalid type for setting \"defaultApp\" given" : "Invalid type for setting \"defaultApp\" given",
    "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "The uploaded file exceeds the upload_max_filesize directive in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The file was only partially uploaded" : "The file was only partially uploaded",
    "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Could not write file to disk" : "Could not write file to disk",
    "A PHP extension stopped the file upload" : "A PHP extension stopped the file upload",
    "No file uploaded" : "No file uploaded",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "You are already using a custom theme. Theming app settings might be overwritten by that.",
    "Theming" : "Theming",
    "Appearance and accessibility" : "Appearance and accessibility",
    "PHP Imagick module" : "PHP Imagick module",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it.",
    "Dark theme with high contrast mode" : "Dark theme with high contrast mode",
    "Enable dark high contrast mode" : "Enable dark high contrast mode",
    "Similar to the high contrast mode, but with dark colours." : "Similar to the high contrast mode, but with dark colours.",
    "Dark theme" : "ໂມດກາງຄືນ",
    "Enable dark theme" : "ນໍາໃຊ້ໂມດກາງຄືນ ",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "A dark theme to ease your eyes by reducing the overall luminosity and brightness.",
    "System default theme" : "System default theme",
    "Enable the system default" : "Enable the system default",
    "Using the default system appearance." : "Using the default system appearance.",
    "Dyslexia font" : "ຕົວອັກສອນ Dyslexia",
    "Enable dyslexia font" : "ເປີດໃຊ້ຟອນ dyslexia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic ເປັນຕົວພິມ/ຕົວອັກສອນຟຣີທີ່ອອກແບບມາເພື່ອຫຼຸດຜ່ອນບາງຄວາມຜິດພາດການອ່ານທົ່ວໄປທີ່ເກີດຈາກອາການຜິດປົກກະຕິໃນການຕໍ່ຄຳສັບ",
    "High contrast mode" : "ໂໝດຄວາມຄົມຊັດສູງ",
    "Enable high contrast mode" : "ເປີດໃຊ້ໂໝດຄວາມຄົມຊັດສູງ",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "ໂໝດຄວາມຄົມຊັດສູງເພື່ອຜ່ອນຄາຍການນຳທາງຂອງທ່ານ. ຄຸນນະພາບການເບິ່ງເຫັນຈະຫຼຸດລົງແຕ່ຄວາມຊັດເຈນຈະເພີ່ມຂຶ້ນ.",
    "Light theme" : "Light theme",
    "Enable the default light theme" : "Enable the default light theme",
    "The default light appearance." : "The default light appearance.",
    "Legal notice" : "Legal notice",
    "Privacy policy" : "ນະໂຍບາຍຄວາມເປັນສ່ວນຕົວ",
    "Adjust the Nextcloud theme" : "Adjust the Nextcloud theme",
    "Could not set global default apps" : "Could not set global default apps",
    "Navigation bar settings" : "Navigation bar settings",
    "Default app" : "Default app",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked.",
    "Use custom default app" : "Use custom default app",
    "Global default app" : "Global default app",
    "Global default apps" : "Global default apps",
    "Default app priority" : "Default app priority",
    "If an app is not enabled for a user, the next app with lower priority is used." : "If an app is not enabled for a user, the next app with lower priority is used.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users.",
    "Name" : "ຊື່",
    "Web link" : "Web link",
    "Slogan" : "Slogan",
    "a safe home for all your data" : "a safe home for all your data",
    "Legal notice link" : "Legal notice link",
    "Privacy policy link" : "Privacy policy link",
    "Background and color" : "Background and color",
    "Primary color" : "Primary color",
    "Background color" : "Background color",
    "Remove background image" : "Remove background image",
    "Background image" : "ຮູບພື້ນຫຼັງ",
    "Favicon" : "Favicon",
    "Logo" : "Logo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on.",
    "Disable user theming" : "Disable user theming",
    "Current selected app: {app}, position {position} of {total}" : "Current selected app: {app}, position {position} of {total}",
    "Move up" : "Move up",
    "Move down" : "Move down",
    "Theme selection is enforced" : "Theme selection is enforced",
    "Could not set the app order" : "Could not set the app order",
    "Could not reset the app order" : "Could not reset the app order",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo.",
    "The default app can not be changed because it was configured by the administrator." : "The default app can not be changed because it was configured by the administrator.",
    "The app order was changed, to see it in action you have to reload the page." : "The app order was changed, to see it in action you have to reload the page.",
    "Reset default app order" : "Reset default app order",
    "Select a background from your files" : "Select a background from your files",
    "Select background" : "Select background",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "The background can be set to an image from the default set, a custom uploaded image, or a plain color.",
    "Custom background" : "Custom background",
    "Plain background" : "Plain background",
    "Default background" : "Default background",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
    "Disable all keyboard shortcuts" : "Disable all keyboard shortcuts",
    "Could not set primary color" : "Could not set primary color",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements.",
    "Reset primary color" : "Reset primary color",
    "Reset to default" : "Reset to default",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
    "Unable to apply the setting." : "Unable to apply the setting.",
    "Appearance and accessibility settings" : "Appearance and accessibility settings",
    "Misc accessibility options" : "Misc accessibility options",
    "Enable blur background filter (may increase GPU load)" : "Enable blur background filter (may increase GPU load)",
    "Customization has been disabled by your administrator" : "Customization has been disabled by your administrator",
    "Disable-user-theming should be true or false" : "Disable-user-theming should be true or false",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema.",
    "Header logo" : "Header logo",
    "Upload new header logo" : "Upload new header logo",
    "Upload new favicon" : "Upload new favicon",
    "User settings" : "User settings",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons.",
    "Upload new logo" : "Upload new logo",
    "Upload new background and login image" : "Upload new background and login image",
    "Background and login image" : "Background and login image",
    "Advanced options" : "Advanced options",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ການເຂົ້າເຖິງທົ່ວໄປແມ່ນມີຄວາມສໍາຄັນຫຼາຍສໍາລັບພວກເຮົາ. ພວກເຮົາປະຕິບັດຕາມມາດຕະຖານເວັບ ແລະກວດສອບເພື່ອເຮັດໃຫ້ທຸກຢ່າງສາມາດໃຊ້ໄດ້ໂດຍບໍ່ໃຊ້ເມົາສ໌, ແລະຊອບແວຊ່ວຍເຫຼືອເຊັ່ນ screenreaders. ພວກເຮົາຕັ້ງເປົ້າໝາຍໃຫ້ສອດຄ່ອງກັບ {guidelines} ຂໍ້ແນະນຳການເຂົ້າຫາເນື້ອຫາເວັບ{linkend} 2.1 ໃນລະດັບ AA, ດ້ວຍຮູບແບບສີສັນຄົມຊັດສູງ ແມ້ແຕ່ຢູ່ໃນລະດັບ AAA.",
    ". Unable to apply the setting." : ". Unable to apply the setting.",
    "No background has been selected" : "No background has been selected",
    "Select a custom color" : "Select a custom color",
    "Upload" : "ອັບໂຫຼດ"
},
"nplurals=1; plural=0;");
